@@ -40,11 +40,8 @@
 
 #include <X11/XKBlib.h>
 #include <X11/extensions/XKBstr.h>
-
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
 #include <X11/extensions/XInput.h>
 #include <X11/extensions/XIproto.h>
-#endif
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -94,14 +91,13 @@ static gpointer manager_object = NULL;
 #define d(str)          do { } while (0)
 #endif
 
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
 static GdkFilterReturn
 devicepresence_filter (GdkXEvent *xevent,
                        GdkEvent  *event,
                        gpointer   data)
 {
         XEvent *xev = (XEvent *) xevent;
-        XEventClass class_presence;
+        G_GNUC_UNUSED XEventClass class_presence;
         int xi_presence;
 
         DevicePresence (gdk_x11_get_default_xdisplay (), xi_presence, class_presence);
@@ -133,7 +129,7 @@ set_devicepresence_handler (MsdA11yKeyboardManager *manager)
 {
         Display *display;
         XEventClass class_presence;
-        int xi_presence;
+        G_GNUC_UNUSED int xi_presence;
 
         if (!supports_xinput_devices ())
                 return;
@@ -154,7 +150,6 @@ set_devicepresence_handler (MsdA11yKeyboardManager *manager)
         if (!gdk_error_trap_pop ())
                 gdk_window_add_filter (NULL, devicepresence_filter, manager);
 }
-#endif
 
 static gboolean
 xkb_enabled (MsdA11yKeyboardManager *manager)
@@ -185,11 +180,7 @@ get_xkb_desc_rec (MsdA11yKeyboardManager *manager)
                 desc->ctrls = NULL;
                 status = XkbGetControls (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), XkbAllControlsMask, desc);
         }
-#if GTK_CHECK_VERSION (3, 0, 0)
         gdk_error_trap_pop_ignored ();
-#else
-        gdk_error_trap_pop ();
-#endif
 
         g_return_val_if_fail (desc != NULL, NULL);
         g_return_val_if_fail (desc->ctrls != NULL, NULL);
@@ -396,11 +387,7 @@ set_server_from_settings (MsdA11yKeyboardManager *manager)
         XkbFreeKeyboard (desc, XkbAllComponentsMask, True);
 
         XSync (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), FALSE);
-#if GTK_CHECK_VERSION (3, 0, 0)
         gdk_error_trap_pop_ignored ();
-#else
-        gdk_error_trap_pop ();
-#endif
 
         mate_settings_profile_end (NULL);
 }
@@ -412,7 +399,9 @@ ax_response_callback (MsdA11yKeyboardManager *manager,
                       guint                   revert_controls_mask,
                       gboolean                enabled)
 {
+#if !GTK_CHECK_VERSION (3, 22, 0)
         GdkScreen *screen;
+#endif
         GError *err;
 
         switch (response_id) {
@@ -437,6 +426,10 @@ ax_response_callback (MsdA11yKeyboardManager *manager,
                 break;
 
         case GTK_RESPONSE_HELP:
+#if GTK_CHECK_VERSION (3, 22, 0)
+                err = NULL;
+                if (!gtk_show_uri_on_window (parent,
+#else
                 if (!parent)
                         screen = gdk_screen_get_default ();
                 else
@@ -444,7 +437,8 @@ ax_response_callback (MsdA11yKeyboardManager *manager,
 
                 err = NULL;
                 if (!gtk_show_uri (screen,
-                                   "help:user-guide#goscustaccess-6",
+#endif
+                                   "help:mate-user-guide/goscustaccess-6",
                                    gtk_get_current_event_time(),
                                    &err)) {
                         GtkWidget *error_dialog = gtk_message_dialog_new (parent,
@@ -1014,9 +1008,7 @@ start_a11y_keyboard_idle_cb (MsdA11yKeyboardManager *manager)
         manager->priv->settings = g_settings_new (CONFIG_SCHEMA);
         g_signal_connect (manager->priv->settings, "changed", G_CALLBACK (keyboard_callback), manager);
 
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
-	set_devicepresence_handler (manager);
-#endif
+        set_devicepresence_handler (manager);
 
         /* Save current xkb state so we can restore it on exit
          */
@@ -1081,11 +1073,7 @@ restore_server_xkb_config (MsdA11yKeyboardManager *manager)
                          XkbAllComponentsMask, True);
 
         XSync (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), FALSE);
-#if GTK_CHECK_VERSION (3, 0, 0)
         gdk_error_trap_pop_ignored ();
-#else
-        gdk_error_trap_pop ();
-#endif
 
         manager->priv->original_xkb_desc = NULL;
 }
@@ -1097,9 +1085,7 @@ msd_a11y_keyboard_manager_stop (MsdA11yKeyboardManager *manager)
 
         g_debug ("Stopping a11y_keyboard manager");
 
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
         gdk_window_remove_filter (NULL, devicepresence_filter, manager);
-#endif
 
         if (p->status_icon)
                 gtk_status_icon_set_visible (p->status_icon, FALSE);
