@@ -107,16 +107,14 @@ static void
 init_screens (MsdMediaKeysManager *manager)
 {
         GdkDisplay *display;
-        int i;
 
         display = gdk_display_get_default ();
-        for (i = 0; i < gdk_display_get_n_screens (display); i++) {
-                GdkScreen *screen;
 
-                screen = gdk_display_get_screen (display, i);
-                if (screen == NULL) {
-                        continue;
-                }
+        GdkScreen *screen;
+
+        screen = gdk_display_get_default_screen (display);
+
+        if (screen != NULL) {
                 manager->priv->screens = g_slist_append (manager->priv->screens, screen);
         }
 
@@ -403,7 +401,11 @@ dialog_show (MsdMediaKeysManager *manager)
         GtkRequisition win_req;
         GdkScreen     *pointer_screen;
         GdkRectangle   geometry;
+#if GTK_CHECK_VERSION (3, 22, 0)
+        GdkMonitor    *monitor;
+#else
         int            monitor;
+#endif
 
         gtk_window_set_screen (GTK_WINDOW (manager->priv->dialog),
                                manager->priv->current_screen);
@@ -441,16 +443,28 @@ dialog_show (MsdMediaKeysManager *manager)
                 /* The pointer isn't on the current screen, so just
                  * assume the default monitor
                  */
+#if GTK_CHECK_VERSION (3, 22, 0)
+                monitor = gdk_display_get_monitor (display, 0);
+#else
                 monitor = 0;
+#endif
         } else {
+#if GTK_CHECK_VERSION (3, 22, 0)
+                monitor = gdk_display_get_monitor_at_point (display, pointer_x, pointer_y);
+#else
                 monitor = gdk_screen_get_monitor_at_point (manager->priv->current_screen,
                                                            pointer_x,
                                                            pointer_y);
+#endif
         }
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+        gdk_monitor_get_geometry (monitor, &geometry);
+#else
         gdk_screen_get_monitor_geometry (manager->priv->current_screen,
                                          monitor,
                                          &geometry);
+#endif
 
         screen_w = geometry.width;
         screen_h = geometry.height;
@@ -1114,7 +1128,7 @@ start_media_keys_idle_cb (MsdMediaKeysManager *manager)
                 mate_settings_profile_start ("gdk_window_add_filter");
 
                 g_debug ("adding key filter for screen: %d",
-                         gdk_screen_get_number (l->data));
+                         gdk_x11_screen_get_screen_number (l->data));
 
                 gdk_window_add_filter (gdk_screen_get_root_window (l->data),
                                        (GdkFilterFunc)acme_filter_events,
